@@ -429,4 +429,26 @@ Rcpp::List check_missing_data_control_units(Rcpp::NumericMatrix subset_data,
   
 }
 
+// [[Rcpp::export()]]
+Rcpp::LogicalVector enforce_strict_histories(Rcpp::List control_histories, int strict_period)
+{
+  Rcpp::LogicalVector indx(control_histories.length());
+  
+  for(int i = 0; i < control_histories.length(); i++)
+  {
+    indx[i] = true;
+    NumericVector temp = control_histories[i];
+    for(int j = temp.length() - 1 - strict_period; j < temp.length(); j++)
+    {
+      if ( NumericVector::is_na(temp[j]) || temp[j] != 0)
+      {
+        indx[i] = false;
+      }
+    }
+  }
+  return indx;
+}
+
+
+
 
